@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "test-simple" "20251030.2148"
+(define-package "test-simple" "20260118.2141"
   "Simple Unit Test Framework for Emacs Lisp."
-  '((cl-lib "0"))
+  '((emacs  "24.4")
+    (compat "30.1.0.1"))
   :url "https://github.com/rocky/emacs-test-simple"
-  :commit "da8ddb6fecb820c8e0809ac0892374e755e4efec"
-  :revdesc "da8ddb6fecb8"
-  :keywords '("unit-test")
+  :commit "502b0d299724256b1bbb08dcff227ac528f1a01a"
+  :revdesc "502b0d299724"
+  :keywords '("lisp")
   :authors '(("Rocky Bernstein" . "rocky@gnu.org"))
   :maintainers '(("Rocky Bernstein" . "rocky@gnu.org")))
